@@ -222,3 +222,30 @@ endfunction
 %! Me = [A, B; C, D];
 %!
 %!assert (Mo, Me, 1e-4);
+
+## matrix exponential
+%!shared Aex, Aexint, Aex_exp, Aexint_exp
+%! A = [  5.0   4.0   3.0   2.0   1.0
+%!        1.0   6.0   0.0   4.0   3.0
+%!        2.0   0.0   7.0   6.0   5.0
+%!        1.0   3.0   1.0   8.0   7.0
+%!        2.0   5.0   7.0   1.0   9.0 ];
+%!
+%! Aex_exp = [ 1.8391   0.9476   0.7920   0.8216   0.7811
+%!             0.3359   2.2262   0.4013   1.0078   1.0957
+%!             0.6335   0.6776   2.6933   1.6155   1.8502
+%!             0.4804   1.1561   0.9110   2.7461   2.0854
+%!             0.7105   1.4244   1.8835   1.0966   3.4134 ];
+%!
+%! Aexint_exp = [ 0.1347   0.0352   0.0284   0.0272   0.0231
+%!                0.0114   0.1477   0.0104   0.0369   0.0368
+%!                0.0218   0.0178   0.1624   0.0580   0.0619
+%!                0.0152   0.0385   0.0267   0.1660   0.0732
+%!                0.0240   0.0503   0.0679   0.0317   0.1863 ];
+%!
+%! [Aex, Aexint] = __sl_mb05nd__ (A, 0.1, 0.0001);
+%!
+%!assert (Aex, Aex_exp, 1e-4);
+%!assert (Aexint, Aexint_exp, 1e-4);
+
+
