@@ -21,7 +21,7 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.1
+## Version: 0.2
 
 function sys = mrdivide (sys1, sys2)
 
@@ -31,13 +31,13 @@ function sys = mrdivide (sys1, sys2)
 
   sys2 = inv (sys2);  # let octave decide which inv() it uses
 
-  [p1, m1] = size (sys1);
-  [p2, m2] = size (sys2);
-
-  if (m2 != p1)
-    error ("lti: mrdivide: system dimensions incompatible: (%dx%d) / (%dx%d)",
-            p1, m1, p2, m2);
-  endif
+  ## [p1, m1] = size (sys1);
+  ## [p2, m2] = size (sys2);
+  ## 
+  ## if (m1 != p2)
+  ##   error ("lti: mrdivide: system dimensions incompatible: (%dx%d) / (%dx%d)",
+  ##           p1, m1, p2, m2);
+  ## endif
 
   sys = sys1 * sys2;
 
