@@ -21,20 +21,26 @@
 
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: September 2009
-## Version: 0.2
+## Version: 0.4
 
 function sys = mtimes (sys2, sys1)
 
-  if (nargin != 2)  # prevent sys = mtimes (sys1, sys2, sys3, ...)
+  if (nargin != 2)                          # prevent sys = mtimes (sys1, sys2, sys3, ...)
     error ("lti: mtimes: this is a binary operator");
   endif
 
   [p1, m1] = size (sys1);
   [p2, m2] = size (sys2);
 
-  if (m2 != p1)
-    error ("lti: mtimes: system dimensions incompatible: (%dx%d) * (%dx%d)",
-            p2, m2, p1, m1);
+  if (m2 != p1)                             # innner dimensions don't match
+    if (p1 == 1 && m1 == 1 && m2 > 1)       # sys1 is SISO, m2 != 0
+      [sys1, p1, m1] = __siso_expansion__ (sys1, m2);
+    elseif (p2 == 1 && m2 == 1 && p1 > 1)   # sys2 is SISO, p1 != 0
+      [sys2, p2, m2] = __siso_expansion__ (sys2, p1);
+    else
+      error ("lti: mtimes: system dimensions incompatible: (%dx%d) * (%dx%d)",
+              p2, m2, p1, m1);
+    endif
   endif
 
   M22 = zeros (m2, p2);
@@ -55,6 +61,19 @@ function sys = mtimes (sys2, sys1)
 endfunction
 
 
+## concatenate lti or matrix sys s times block-diagonally
+## despite its name, it also works for MIMO systems.
+function [sys, p, m] = __siso_expansion__ (sys, s)
+
+  tmp = cell (s, 1);
+  tmp(1:s) = sys;
+  sys = blkdiag (tmp{:});
+
+  [p, m] = size (sys);
+
+endfunction
+
+
 ## Alternative code: consistency vs. compatibility
 #{
   M11 = zeros (m1, p1);
