@@ -24,7 +24,7 @@
 ## Special thanks to Vasile Sima and Andras Varga for their advice.
 ## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 ## Created: October 2009
-## Version: 0.5
+## Version: 0.7
 
 function [retsys, retlti] = __sys2ss__ (sys)
 
@@ -47,6 +47,8 @@ function [retsys, retlti] = __sys2ss__ (sys)
   if (any (tmp(:)))       # non-proper transfer function
     ## separation into strictly proper and polynomial part
     [numq, numr] = cellfun (@deconv, num, den, "uniformoutput", false);
+    numr = cellfun (@(num_v, len_d) num_v(end-len_d+2:end), ...
+                    numr, num2cell (len_den), "uniformoutput", false);
     numq = cellfun (@__remove_leading_zeros__, numq, "uniformoutput", false);
     numr = cellfun (@__remove_leading_zeros__, numr, "uniformoutput", false);
 
@@ -80,10 +82,6 @@ function [a, b, c, d] = __proper_tf2ss__ (num, den, p, m)
   numc = cell (p, m);
   denc = cell (p, 1);
 
-  ## set zero denominators to 1 for convolution
-  zero_idx = cellfun (@(x) all (x == 0), den);
-  den(zero_idx) = 1;
-  
   ## multiply all denominators in a row and
   ## update each numerator accordingly
   ## except for single-input models and those
@@ -101,19 +99,9 @@ function [a, b, c, d] = __proper_tf2ss__ (num, den, p, m)
     endif
   endfor
 
-  ## set numerators to zero if their denominators are zero
-  numc(zero_idx) = 0;
-
   len_numc = cellfun (@length, numc);
   len_denc = cellfun (@length, denc);
 
-  ## check for properness  
-  ## tfpoly ensures that there are no leading zeros
-  ## tmp = len_numc > repmat (len_denc, 1, m);
-  ## if (any (tmp(:)))
-  ##   error ("tf: tf2ss: system must be proper");
-  ## endif
-
   ## create arrays and fill in the data
   ## in a way that Slicot TD04AD can use
   max_len_denc = max (len_denc(:));
@@ -173,12 +161,12 @@ endfunction
 ## remove leading zeros from polynomial vector
 function p = __remove_leading_zeros__ (p)
 
-  idx = find (p != 0);
+  idx = find (p != 0, 1);
 
   if (isempty (idx))
     p = 0;
   else
-    p = p(idx(1) : end);  # p(idx) would remove all zeros
+    p = p(idx : end);
   endif
 
 endfunction
