@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -29,10 +29,10 @@ function [nr, ordsel] = __modred_check_order__ (nr, n)
   endif
 
   if (nr > n)
-    error ("modred: order of reduced model (%d) can't be larger than the original one (%d)", \
+    error ("modred: order of reduced model (%d) can't be larger than the original one (%d)", ...
            nr, n);
   endif
   
   ordsel = 0;
 
-endfunction
\ No newline at end of file
+endfunction
