@@ -1,4 +1,4 @@
-## Copyright (C) 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -28,7 +28,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item G
-## LTI model of the open-loop plant (A,B,C,D).
+## @acronym{LTI} model of the open-loop plant (A,B,C,D).
 ## It has m inputs, p outputs and n states.
 ## @item F
 ## Stabilizing state feedback matrix (m-by-n).
@@ -183,12 +183,12 @@ function [Kr, info] = cfconred (G, F, L, varargin)
   jobd = any (d(:));
 
   if (mf != m || nf != n)
-    error ("cfconred: dimensions of state-feedback matrix (%dx%d) and plant (%dx%d, %d states) don't match", \
+    error ("cfconred: dimensions of state-feedback matrix (%dx%d) and plant (%dx%d, %d states) don't match", ...
            mf, nf, p, m, n);
   endif
 
   if (nl != n || pl != p)
-    error ("cfconred: dimensions of observer matrix (%dx%d) and plant (%dx%d, %d states) don't match", \
+    error ("cfconred: dimensions of observer matrix (%dx%d) and plant (%dx%d, %d states) don't match", ...
            nl, pl, p, m, n);
   endif
 
@@ -260,7 +260,7 @@ function [Kr, info] = cfconred (G, F, L, varargin)
   endif
 
   ## perform model order reduction
-  [acr, bcr, ccr, dcr, ncr, hsv] = __sl_sb16bd__ (a, b, c, d, dt, equil, ncr, ordsel, jobd, jobmr, \
+  [acr, bcr, ccr, dcr, ncr, hsv] = __sl_sb16bd__ (a, b, c, d, dt, equil, ncr, ordsel, jobd, jobmr, ...
                                                   F, L, jobcf, tol1, tol2);
   
   ## assemble reduced order controller
