@@ -1,4 +1,4 @@
-## Copyright (C) 2009, 2010, 2011   Lukas F. Reichlin
+## Copyright (C) 2009-2014   Lukas F. Reichlin
 ##
 ## This file is part of LTI Syncope.
 ##
@@ -27,7 +27,7 @@
 ## @strong{Inputs}
 ## @table @var
 ## @item sys
-## Continuous- or discrete-time LTI system.
+## Continuous- or discrete-time @acronym{LTI} system.
 ## @item a
 ## State matrix (n-by-n) of a continuous-time system.
 ## @item b
